|Build Status| |Coverage Status| |PyPI Version| |PyPI Downloads| |Wheel Status|

Brownant
========

Brownant is a lightweight web data extracting framework.


Who uses it?
------------

At the moment, `dongxi.douban.com <http://dongxi.douban.com>`_
(a.k.a. Douban Dongxi) uses Brownant in production environment.


Installation
------------

::

    $ pip install brownant


Links
-----

- `Document <https://brownant.readthedocs.org>`_
- `Issue Track <https://github.com/douban/brownant/issues>`_


Issues
------

If you want to report bugs or request features, please create issues on
`GitHub Issues <https://github.com/douban/brownant/issues>`_.


Contributes
-----------

You can send a pull reueqst on
`GitHub <https://github.com/douban/brownant/pulls>`_.


.. |Build Status| image:: https://travis-ci.org/douban/brownant.svg?branch=master,develop
   :target: https://travis-ci.org/douban/brownant
   :alt: Build Status
.. |Coverage Status| image:: https://img.shields.io/coveralls/douban/brownant/develop.svg
   :target: https://coveralls.io/r/douban/brownant
   :alt: Coverage Status
.. |Wheel Status| image:: https://img.shields.io/pypi/wheel/brownant.svg
   :target: https://pypi.python.org/pypi/brownant
   :alt: Wheel Status
.. |PyPI Version| image:: https://img.shields.io/pypi/v/brownant.svg
   :target: https://pypi.python.org/pypi/brownant
   :alt: PyPI Version
.. |PyPI Downloads| image:: https://img.shields.io/pypi/dm/brownant.svg
   :target: https://pypi.python.org/pypi/brownant
   :alt: Downloads
